PhoneField class

Inheritance

Constructors

PhoneField({Key? key, required TextEditingController controller, required String hint, Icon? prefixIcon = defaultIcon, String? phoneUser, bool usePhoneUser = false, bool isRequired = true, bool readOnly = false, bool? enable, double borderRadius = 5, Color borderColor = const Color.fromRGBO(220, 220, 220, 1), Color borderFocusedColor = const Color.fromRGBO(220, 220, 220, 1), TextInputType inputType = TextInputType.text, String? validator(String?)?, String? onChanged(String?)?})

Properties

borderColor Color
getter/setter pair
borderFocusedColor Color
getter/setter pair
borderRadius double
getter/setter pair
controller TextEditingController
getter/setter pair
enable bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hint String
getter/setter pair
inputType TextInputType
getter/setter pair
isRequired bool
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged String? Function(String?)?
final
phoneUser String?
getter/setter pair
prefixIcon Icon?
getter/setter pair
readOnly bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usePhoneUser bool
getter/setter pair
validator String? Function(String?)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() PhoneFieldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultIcon → const Icon