Utils class
Constructors
- Utils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
capitalize(
String value) → String -
deleleValue(
{required String key}) → dynamic -
getValue(
{required String key}) → dynamic -
height(
BuildContext context) → double -
isAndroid(
BuildContext context) → dynamic -
pusher(
BuildContext context, Widget destination) → dynamic -
pusherRemove(
BuildContext context, Widget destination) → dynamic -
storeValue(
{required String key, required String value}) → dynamic -
width(
BuildContext context) → double
Constants
- storage → const FlutterSecureStorage